@@ -22,7 +22,8 @@ def test_upload_config(rayvision_upload, tmpdir):
         rayvision_upload.upload_config(task_id, config_file_list)
 
 
-def test_create_db_ini(rayvision_upload):
+def test_create_db_ini(rayvision_upload, tmpdir):
     """Test create_db_ini, we can get a db file."""
-    rayvision_upload.create_db_ini()
+    upload_json_path = str(tmpdir.join("upload.json"))
+    rayvision_upload.create_db_ini(upload_json_path)
     assert len(os.listdir(rayvision_upload.db_ini)) > 0
